@@ -188,7 +188,10 @@ class OOSheet(OODoc):
                 yield self.sheet.getCellByPosition(col, row)
 
     def __repr__(self):
-        return self.selector
+        try:
+            return self.selector
+        except AttributeError:
+            return 'empty OOSheet() object'
 
     @property
     def width(self):
@@ -376,6 +379,19 @@ class OOSheet(OODoc):
         self.end_col += num
         return self
 
+    @property
+    def first_row(self):
+        return self.clone().shrink_down(self.height - 1)
+    @property
+    def last_row(self):
+        return self.clone().shrink_up(self.height - 1)
+    @property
+    def first_column(self):
+        return self.clone().shrink_right(self.width - 1)
+    @property
+    def last_column(self):
+        return self.clone().shrink_left(self.width - 1)
+    
     def copy(self):
         """Focuses and copies the contents, so it can be pasted somewhere else"""
         self.focus()
@@ -498,19 +514,24 @@ class OOSheet(OODoc):
         
     def shift_until(self, col, row, *args, **kwargs):
         """Moves the selector in direction given by "col" and "row" parameters, until a condition is satisfied.
+
         If selector is a single cell, than a value can be given as parameter and shift will be done until
         that exact value is found.
+        
         For multiple cells selectors, the parameters can be in one of the following forms:
-           column_LABEL = value
-           row_NUMBER = value
-           column_LABEL_satisfies = lambda
-           row_NUMBER_satisfies = lambda
+        
+        - column_LABEL = value
+        - row_NUMBER = value
+        - column_LABEL_satisfies = lambda
+        - row_NUMBER_satisfies = lambda
 
         If column is given as condition, then shift must be horizontal, and vice-versa.
+        
         If matching against a value, the type of the value given will be checked and either "value", "string"
         or "date" property of cell will be used.
-        If matching against a lambda function, a python-uno com.sun.star.table.XCell object will be given
-        as parameter to the lambda function.
+        
+        If matching against a lambda function, a single-cell OOSheet object will be given as parameter
+        to the lambda function.
         """
         
         assert col != 0 or row != 0
@@ -600,6 +621,30 @@ class OOSheet(OODoc):
         """Add rows after selector"""
         return self.grow(0, num)
 
+    def grow_until(self, col, row, *args, **kwargs):
+        """Grows the selection in direction given by "col" and "row" parameters, until a condition is satisfied.
+        Conditions are same as shift_until().
+        """
+        other = self.clone().shift_until(col, row, *args, **kwargs)
+        self.start_row = min(self.start_row, other.start_row)
+        self.end_row = max(self.end_row, other.end_row)
+        self.start_col = min(self.start_col, other.start_col)
+        self.end_col = max(self.end_col, other.end_col)
+        return self
+        
+    def grow_right_until(self, *args, **kwargs):
+        """Expands selection to right until condition is matched. Conditions are same as shift_until()"""
+        return self.grow_until(1, 0, *args, **kwargs)
+    def grow_left_until(self, *args, **kwargs):
+        """Expands selection to left until condition is matched. Conditions are same as shift_until()"""
+        return self.grow_until(-1, 0, *args, **kwargs)
+    def grow_down_until(self, *args, **kwargs):
+        """Expands selection down until condition is matched. Conditions are same as shift_until()"""
+        return self.grow_until(0, 1, *args, **kwargs)
+    def grow_up_until(self, *args, **kwargs):
+        """Expands selection up until condition is matched. Conditions are same as shift_until()"""
+        return self.grow_until(0, -1, *args, **kwargs)
+
     def shrink(self, col, row):
         """Reduces the size of the selector, in same logic as grow()"""
         if col < 0:
@@ -623,12 +668,29 @@ class OOSheet(OODoc):
         """Removes columns from left of selector. Does not afect data, only the selector."""
         return self.shrink(-num, 0)
     def shrink_up(self, num = 1):
-        """Removes rows from beginning of selector. Does not afect data, only the selector."""
+        """Removes rows from top of selector. Does not afect data, only the selector."""
         return self.shrink(0, -num)
     def shrink_down(self, num = 1):
-        """Removes rows from end of selector. Does not afect data, only the selector."""
+        """Removes rows from bottom of selector. Does not afect data, only the selector."""
         return self.shrink(0, num)
 
+    def shrink_right_until(self, *args, **kwargs):
+        """Reduces selection on right border until condition is matched. Conditions are same as shift_until()"""
+        self.end_col = self.last_column.shift_left_until(*args, **kwargs).end_col
+        return self
+    def shrink_left_until(self, *args, **kwargs):
+        """Reduces selection on left border until condition is matched. Conditions are same as shift_until()"""
+        self.start_col = self.first_column.shift_right_until(*args, **kwargs).start_col
+        return self
+    def shrink_down_until(self, *args, **kwargs):
+        """Reduces selection on bottom border until condition is matched. Conditions are same as shift_until()"""
+        self.end_row = self.last_row.shift_up_until(*args, **kwargs).end_row
+        return self
+    def shrink_up_until(self, *args, **kwargs):
+        """Reduces selection on top border until condition is matched. Conditions are same as shift_until()"""
+        self.start_row = self.first_row.shift_down_until(*args, **kwargs).start_row
+        return self
+
     def clone(self):
         """Returns a clone of this selector.
         Useful to preserve a state before calls that modify the selector.
